from django.conf import settings
from django.contrib.auth.models import Group, Permission
from django.core.management.base import BaseCommand


class Command(BaseCommand):
    help = "add permissions"

    def handle(self, *args, **options):
        program_group = Group.objects.get(name=settings.PRIVILEGED_GROUP)
        app_permissions = Permission.objects.filter(content_type__app_label="program").exclude(
            codename__startswith="edit"
        )
        self.stdout.write(
            "  Adding app permissions to the privileged group... ",
            ending="",
        )
        self.stdout.flush()
        program_group.permissions.add(*app_permissions)
        self.stdout.write(self.style.SUCCESS(len(app_permissions)))

        broadcast_group = Group.objects.get(name=settings.ENTITLED_GROUPS[0])
        model_permissions = Permission.objects.filter(
            content_type__model__in=["note", "notelink"]
        ).exclude(codename__startswith="edit")
        self.stdout.write(
            "  Adding model permissions on note & notelink to the first entitled group... ",
            ending="",
        )
        self.stdout.flush()
        broadcast_group.permissions.add(*model_permissions)
        self.stdout.write(self.style.SUCCESS(len(model_permissions)))

        broadcast_plus_group = Group.objects.get(name=settings.ENTITLED_GROUPS[1])
        edit_permissions = Permission.objects.filter(
            codename__startswith="edit", content_type__model__in=["host", "note", "show"]
        )
        self.stdout.write(
            "  Adding edit permissions on host, note & show to the second entitled group... ",
            ending="",
        )
        self.stdout.flush()
        broadcast_plus_group.permissions.add(*edit_permissions)
        self.stdout.write(self.style.SUCCESS(len(edit_permissions)))
